@@ -3,7 +3,7 @@ import dataclasses
 import enum
 import typing
 
-from .external import interface, mg5, positivity, vrap, yad
+from .external import integrability, interface, mg5, positivity, vrap, yad
 
 
 class Kind(enum.Enum):
@@ -11,6 +11,7 @@ class Kind(enum.Enum):
     positivity = enum.auto()
     ftdy = enum.auto()
     hadronic = enum.auto()
+    integrability = enum.auto()
 
 
 @dataclasses.dataclass
@@ -29,5 +30,9 @@ def label(dataset: str) -> Info:
         )
     if vrap.is_vrap(dataset):
         return Info(color="green", external=vrap.Vrap, kind=Kind.ftdy)
+    if integrability.is_integrability(dataset):
+        return Info(
+            color="brown", external=integrability.Integrability, kind=Kind.integrability
+        )
 
     return Info(color="blue", external=mg5.Mg5, kind=Kind.hadronic)
